%% Marynel Vazquez (marynel@cmu.edu)
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{futurerobotsbook}[2011/04/29 Future Robots book class]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions\relax % process options

\LoadClass{book}

% Minimal class file
\renewcommand{\normalsize}{\fontsize{10pt}{12pt}\selectfont} 
\setlength{\textwidth}{6.5in} 
\setlength{\textheight}{8in}

% Color
\RequirePackage{color}
\definecolor{orangebb}{rgb}{1,0.5,0}
\definecolor{myblue}{rgb}{0.11,0.46,0.74}

% Font
\RequirePackage{fix-cm}
\RequirePackage[T1]{fontenc}
%% \RequirePackage{fourier}

% Fancy header
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\fancyhf{}
%% \fancyhead[LE,RO]{\scshape\thepage}
\fancyhead[LE,RO]{}
\fancypagestyle{plain}{%
 \fancyhead{}
 \renewcommand{\headrulewidth}{0pt}
}

\renewcommand{\chaptermark}[1]{\markboth{#1}{}}
\renewcommand{\sectionmark}[1]{\markright{\thesection\ #1}}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
\addtolength{\headheight}{0.2pt}
\setlength{\footskip}{0in}
\setlength{\oddsidemargin}{0.3cm}
\setlength{\evensidemargin}{0.3cm}
\renewcommand{\footruleskip}{0pt}
\renewcommand{\headsep}{0pt}

\setlength{\parindent}{0pt}

% Images & Tables
\RequirePackage[pdftex]{graphicx}
\RequirePackage{multirow}

% Front matter
\renewcommand{\frontmatter}{%
  \cleardoublepage%
  \@mainmatterfalse%
  %% \pagenumbering{arabic}%
  %\pagestyle{plain}%
  \fancyhf{}%
  %% \fancyhead[LE,RO]{\thepage}
  \fancyfoot[LE,RO]{\thepage}
}

\renewcommand\mainmatter{%
  \cleardoublepage%
  \@mainmattertrue%
  \fancyhf{}%
  \renewcommand{\chaptermark}[1]{\markboth{##1}{}}%
  \fancyhead[LO]{\bfseries\rightmark}
  \fancyhead[RE]{\bfseries\leftmark}
  \fancyfoot[LE,RO]{\thepage}
}

% Lists
\renewcommand{\labelitemi}{-}

%Graphics
\RequirePackage[pdftex]{graphicx}
\RequirePackage{sidecap}
%\RequirePackage{subfigure}

% Title
\renewcommand{\maketitle}
{
  \begin{titlepage}
    %% \null\vfil
    %% \vskip 200\p@
  \vspace*{90\p@}
    \begin{center}%
      \bfseries {\fontsize{64}{72}\selectfont \textcolor{myblue}{\@title}}
     %% {\LARGE \@title \par}%
     \vskip 1em%
     {\Huge %\large
      \lineskip .75em%
       \begin{tabular}[t]{c}%
         \@author. IACD, Spring 2011
       \end{tabular}\par}%
       \vskip 1.5em%
     {\Large \@date \par}%       % Set date in \large size.
   \end{center}\par
    \raggedleft
  \includegraphics[width=0.65\linewidth]{images/cover}
  \end{titlepage}
}

% Chapters
\newcommand{\yearchapter}[1]
{
  \thispagestyle{empty}
  \vspace*{300\p@}
  \raggedleft \bfseries {\fontsize{64}{72}\selectfont #1}\\
  {\Huge years from now}\\

  \newpage
}

% Sections
\newcommand{\actionsection}[1]
{
  \fancyhead[LE,LO]{\ \Large #1 \vspace{.01pt} }
  \fancyhead[RE,RO]{
    \includegraphics[width=1.3in]{images/emotions_nolabel}\hspace{0.75em}}
}

\newcommand{\actionemotionswill}[1]
{
  %% \thispagestyle{empty}%
  \vspace*{100\p@}
  \begin{center}
    \bfseries {\fontsize{24}{32}\selectfont In #1 years, robots may
      make us feel...}\\ \vspace{-3em}
    \includegraphics[width=0.8\linewidth]{images/emotions_will#1}
    \includegraphics[width=0.8\linewidth]{images/emotions}
  \end{center}
  \fancyhead[LE,RO,RE,LO]{}
  \fancyfoot[LE,RO]{\thepage}

  \newpage
}

\newcommand{\goodness}[1]
{
  
  \vspace*{30\p@}
  \begin{center}
    \bfseries {\fontsize{24}{32}\selectfont Are these robots\\[0.5em] good for
      our future?}\\ \vspace{-10em}
    \includegraphics[width=0.55\linewidth, height=3in]{images/goodness_#1}
    \includegraphics[width=0.8\linewidth]{images/goodness_labels}
  \end{center}
  \fancyhead[LE,RO,RE,LO]{}
  \fancyfoot[LE,RO]{\thepage}

  \newpage
}

% Robots
\newcommand{\robotidea}[4]
{
  \begin{minipage}[t][1.54in]{\linewidth}
    \begin{tabular}{lp{8.13cm}r}
    %% \begin{tabular*}{1.0\textwidth}{ll@{\extracolsep{\fill}}r}
      \hline \\[-0.9em]
      \multirow{3}{*}{\includegraphics[height=1.5in]{#1.jpg}} & &
      \multirow{3}{*}{\includegraphics[width=1.3in]{#3}}\\ 
      & {\normalsize \textnormal{#2} } & \\
      & \includegraphics[width=1in]{#4} &\\ 
    %% \end{tabular*}
    \end{tabular}
  \end{minipage}
}
